==> jc-1.4.0.tar.gz: javax/print/ServiceUIFactory.h <==
// public abstract class javax.print.ServiceUIFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dab8b57969f26efc javax_print_ServiceUIFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_ServiceUIFactory_H_
#define _JC_javax_print_ServiceUIFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_ServiceUIFactory$sub_refs	_jc_javax_print_ServiceUIFactory$sub_refs;
typedef struct _jc_javax_print_ServiceUIFactory$sub_nonrefs	_jc_javax_print_ServiceUIFactory$sub_nonrefs;
typedef struct _jc_javax_print_ServiceUIFactory$refs	_jc_javax_print_ServiceUIFactory$refs;
typedef struct _jc_javax_print_ServiceUIFactory$nonrefs	_jc_javax_print_ServiceUIFactory$nonrefs;
typedef struct _jc_javax_print_ServiceUIFactory$object	_jc_javax_print_ServiceUIFactory$object;

typedef struct _jc_javax_print_ServiceUIFactory$fields_struct	_jc_javax_print_ServiceUIFactory$fields_struct;
typedef const struct _jc_javax_print_ServiceUIFactory$vmethods	_jc_javax_print_ServiceUIFactory$vmethods;
typedef const struct _jc_javax_print_ServiceUIFactory$vtable	_jc_javax_print_ServiceUIFactory$vtable;
typedef const struct _jc_javax_print_ServiceUIFactory$vtype	_jc_javax_print_ServiceUIFactory$vtype;

// Class fields structure
struct _jc_javax_print_ServiceUIFactory$fields_struct {
	struct _jc_java_lang_String$object	*DIALOG__5fUI;
	struct _jc_java_lang_String$object	*JCOMPONENT__5fUI;
	struct _jc_java_lang_String$object	*JDIALOG__5fUI;
	struct _jc_java_lang_String$object	*PANEL__5fUI;
	jint	ABOUT__5fUIROLE;
	jint	ADMIN__5fUIROLE;
	jint	MAIN__5fUIROLE;
	jint	RESERVED__5fUIROLE;
};
extern _jc_javax_print_ServiceUIFactory$fields_struct _jc_javax_print_ServiceUIFactory$class_fields;

// Constructors
extern void _jc_javax_print_ServiceUIFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_print_ServiceUIFactory$method$getUI$a2fad811965335e6(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint, struct _jc_java_lang_String$object *);
extern _jc_object_array *_jc_javax_print_ServiceUIFactory$method$getUIClassNamesForRole$fbff22c5c4d9fe06(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_print_ServiceUIFactory$method_info$getUI$a2fad811965335e6;
extern _jc_method _jc_javax_print_ServiceUIFactory$method_info$getUIClassNamesForRole$fbff22c5c4d9fe06;

// Virtual methods structure
struct _jc_javax_print_ServiceUIFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getUI$a2fad811965335e6)(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint, struct _jc_java_lang_String$object *);
	_jc_object_array	*(*getUIClassNamesForRole$fbff22c5c4d9fe06)(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint);
};

// Vtable
struct _jc_javax_print_ServiceUIFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_ServiceUIFactory$vmethods	javax_print_ServiceUIFactory;
};

// Vtype
struct _jc_javax_print_ServiceUIFactory$vtype {
	_jc_type			type;
	_jc_javax_print_ServiceUIFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_ServiceUIFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_ServiceUIFactory$refs {
    _jc_javax_print_ServiceUIFactory$sub_refs	javax_print_ServiceUIFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_ServiceUIFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_ServiceUIFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_ServiceUIFactory$sub_nonrefs	javax_print_ServiceUIFactory;
};

// Object instance structure
struct _jc_javax_print_ServiceUIFactory$object {
	_jc_javax_print_ServiceUIFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_ServiceUIFactory$vtype	*vtype;
	_jc_javax_print_ServiceUIFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_ServiceUIFactory$vtype _jc_javax_print_ServiceUIFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_ServiceUIFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_ServiceUIFactory$class_object;

#endif	/* _JC_javax_print_ServiceUIFactory_H_ */

==> jc-1.4.6.tar.gz: javax/print/ServiceUIFactory.h <==
// public abstract class javax.print.ServiceUIFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dab8b57969f26efc javax_print_ServiceUIFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_ServiceUIFactory_H_
#define _JC_javax_print_ServiceUIFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_ServiceUIFactory$sub_refs	_jc_javax_print_ServiceUIFactory$sub_refs;
typedef struct _jc_javax_print_ServiceUIFactory$sub_nonrefs	_jc_javax_print_ServiceUIFactory$sub_nonrefs;
typedef struct _jc_javax_print_ServiceUIFactory$refs	_jc_javax_print_ServiceUIFactory$refs;
typedef struct _jc_javax_print_ServiceUIFactory$nonrefs	_jc_javax_print_ServiceUIFactory$nonrefs;
typedef struct _jc_javax_print_ServiceUIFactory$object	_jc_javax_print_ServiceUIFactory$object;

typedef struct _jc_javax_print_ServiceUIFactory$fields_struct	_jc_javax_print_ServiceUIFactory$fields_struct;
typedef const struct _jc_javax_print_ServiceUIFactory$vmethods	_jc_javax_print_ServiceUIFactory$vmethods;
typedef const struct _jc_javax_print_ServiceUIFactory$vtable	_jc_javax_print_ServiceUIFactory$vtable;
typedef const struct _jc_javax_print_ServiceUIFactory$vtype	_jc_javax_print_ServiceUIFactory$vtype;

// Class fields structure
struct _jc_javax_print_ServiceUIFactory$fields_struct {
	struct _jc_java_lang_String$object	*DIALOG__5fUI;
	struct _jc_java_lang_String$object	*JCOMPONENT__5fUI;
	struct _jc_java_lang_String$object	*JDIALOG__5fUI;
	struct _jc_java_lang_String$object	*PANEL__5fUI;
	jint	ABOUT__5fUIROLE;
	jint	ADMIN__5fUIROLE;
	jint	MAIN__5fUIROLE;
	jint	RESERVED__5fUIROLE;
};
extern _jc_javax_print_ServiceUIFactory$fields_struct _jc_javax_print_ServiceUIFactory$class_fields;

// Constructors
extern void _jc_javax_print_ServiceUIFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_print_ServiceUIFactory$method$getUI$a2fad811965335e6(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_print_ServiceUIFactory$method$getUIClassNamesForRole$fbff22c5c4d9fe06(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_ServiceUIFactory$method_info$getUI$a2fad811965335e6;
extern _jc_method _jc_javax_print_ServiceUIFactory$method_info$getUIClassNamesForRole$fbff22c5c4d9fe06;

// Virtual methods structure
struct _jc_javax_print_ServiceUIFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getUI$a2fad811965335e6)(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getUIClassNamesForRole$fbff22c5c4d9fe06)(_jc_env *, struct _jc_javax_print_ServiceUIFactory$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_ServiceUIFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_ServiceUIFactory$vmethods	javax_print_ServiceUIFactory;
};

// Vtype
struct _jc_javax_print_ServiceUIFactory$vtype {
	_jc_type			type;
	_jc_javax_print_ServiceUIFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_ServiceUIFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_ServiceUIFactory$refs {
    _jc_javax_print_ServiceUIFactory$sub_refs	javax_print_ServiceUIFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_ServiceUIFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_ServiceUIFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_ServiceUIFactory$sub_nonrefs	javax_print_ServiceUIFactory;
};

// Object instance structure
struct _jc_javax_print_ServiceUIFactory$object {
	_jc_javax_print_ServiceUIFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_ServiceUIFactory$vtype	*vtype;
	_jc_javax_print_ServiceUIFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_ServiceUIFactory$vtype _jc_javax_print_ServiceUIFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_ServiceUIFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_ServiceUIFactory$class_object;

#endif	/* _JC_javax_print_ServiceUIFactory_H_ */
